@@ -13,7 +13,7 @@ G_BEGIN_DECLS
 
 #define GST_GL_HAVE_OPENGL 0
 #define GST_GL_HAVE_GLES2 1
-#define GST_GL_HAVE_GLES3 0
+#define GST_GL_HAVE_GLES3 1
 
 #define GST_GL_HAVE_WINDOW_X11 1
 #define GST_GL_HAVE_WINDOW_COCOA 0
@@ -22,6 +22,7 @@ G_BEGIN_DECLS
 #define GST_GL_HAVE_WINDOW_ANDROID 0
 #define GST_GL_HAVE_WINDOW_DISPMANX 0
 #define GST_GL_HAVE_WINDOW_EAGL 0
+#define GST_GL_HAVE_WINDOW_VIV_FB 0
 
 #define GST_GL_HAVE_PLATFORM_EGL 1
 #define GST_GL_HAVE_PLATFORM_GLX 0
@@ -30,14 +31,16 @@ G_BEGIN_DECLS
 #define GST_GL_HAVE_PLATFORM_EAGL 0
 
 #define GST_GL_HAVE_DMABUF 1
+#define GST_GL_HAVE_VIV_DIRECTVIV 0
 
-#define GST_GL_HAVE_GLEGLIMAGEOES 1
+#define GST_GL_HAVE_GLEGLIMAGEOES 0
 #define GST_GL_HAVE_GLCHAR 1
 #define GST_GL_HAVE_GLSIZEIPTR 1
 #define GST_GL_HAVE_GLINTPTR 1
 #define GST_GL_HAVE_GLSYNC 1
 #define GST_GL_HAVE_GLUINT64 1
 #define GST_GL_HAVE_GLINT64 1
+#define GST_GL_HAVE_EGLATTRIB 1
 
 
 G_END_DECLS
